@@ -4,7 +4,7 @@ use vtables_derive::*;
 #[has_vtable]
 #[derive(VTable)]
 pub struct IPanel {
-	pub vtable: usize
+	pub vtable: usize,
 }
 
 impl IPanel {
@@ -13,4 +13,4 @@ impl IPanel {
 
 	#[virtual_index(41)]
 	pub fn PaintTraverse(&self, vguiPanel: u32, forceRepaint: bool, allowForce: bool) {}
-}
\ No newline at end of file
+}
