@@ -1,3 +1,3 @@
 pub use crate::lua_shared::*;
 pub use crate::types::{LuaCFunction, LuaInteger, LuaNumber, LuaState, LuaString};
-pub use crate::{cstr, rstr};
+pub use crate::{cstr, rstr, printgm};
